summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--django/db/backends/mysql/features.py12
1 files changed, 9 insertions, 3 deletions
diff --git a/django/db/backends/mysql/features.py b/django/db/backends/mysql/features.py
index a37fe81cbd..1a9f5da39e 100644
--- a/django/db/backends/mysql/features.py
+++ b/django/db/backends/mysql/features.py
@@ -51,9 +51,15 @@ class DatabaseFeatures(BaseDatabaseFeatures):
@cached_property
def test_collations(self):
charset = 'utf8'
- if self.connection.mysql_is_mariadb and self.connection.mysql_version >= (10, 6):
- # utf8 is an alias for utf8mb3 in MariaDB 10.6+.
- charset = 'utf8mb3'
+ if (
+ self.connection.mysql_is_mariadb
+ and self.connection.mysql_version >= (10, 6)
+ ) or (
+ not self.connection.mysql_is_mariadb
+ and self.connection.mysql_version >= (8, 0, 30)
+ ):
+ # utf8 is an alias for utf8mb3 in MariaDB 10.6+ and MySQL 8.0.30+.
+ charset = "utf8mb3"
return {
'ci': f'{charset}_general_ci',
'non_default': f'{charset}_esperanto_ci',